Puck.Content.Part (Puck v0.2.7)
View SourceA single content part within a message.
This is the core struct that represents any type of content.
Use the factory functions in Puck.Content to create parts.
A single content part within a message.
This is the core struct that represents any type of content.
Use the factory functions in Puck.Content to create parts.