Struct representing a runtime sandbox instance.
This is a lightweight handle to an existing sandbox. The actual sandbox
state lives in the infrastructure (Docker container, Fly machine, etc.)
and should be queried via Puck.Sandbox.Runtime.status/1.
Summary
Functions
Creates a new Instance struct with the given attributes.